-- autocmd

-- Disable autocommenting on new lines under commented ones

vim.api.nvim_create_autocmd("Filetype", {
	pattern = "*", 
	command = "setlocal formatoptions-=c formatoptions-=r formatoptions-=o"
})

-- Filetype specific mappings

-- Compile and show LaTeX
vim.api.nvim_create_autocmd("Filetype", {
	pattern = "tex",
	callback = function()
		vim.api.nvim_buf_set_keymap(0, "n", "<leader>c", ":exec '!xelatex %'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "n", "<F5>", ":exec '!xelatex %'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "i", "<F5>", ":exec '!xelatex %'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "v", "<F5>", ":exec '!xelatex %'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "n", "<F6>", ":silent !zathura --fork %:r.pdf& <cr>", {})
		vim.api.nvim_buf_set_keymap(0, "i", "<F6>", "<esc> :silent !zathura --fork %:r.pdf& <cr>", {})
		vim.api.nvim_buf_set_keymap(0, "v", "<F6>", "<esc> :silent !zathura --fork %:r.pdf& <cr>", {})
	end
})

-- Compile C
vim.api.nvim_create_autocmd("Filetype", {
	pattern = "c",
	callback = function()
		vim.api.nvim_buf_set_keymap(0, "n", "<leader>c", ":exec '!gcc % -o %<'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "n", "<F5>", ":exec '!gcc % -o %<'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "i", "<F5>", ":exec '!gcc % -o %<'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "v", "<F5>", ":exec '!gcc % -o %<'<cr>", {})
	end
})

-- run Python
vim.api.nvim_create_autocmd("Filetype", {
	pattern = "python",
	callback = function()
		vim.api.nvim_buf_set_keymap(0, "n", "<leader>c", ":exec '!python3 %'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "n", "<F5>", ":exec '!python3 %'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "i", "<F5>", ":exec '!python3 %'<cr>", {})
		vim.api.nvim_buf_set_keymap(0, "v", "<F5>", ":exec '!python3 %'<cr>", {})
	end
})

-- Close nvim if only Nvim-Tree is open
vim.api.nvim_create_autocmd("BufEnter", {
	nested = true,
	callback = function()
		if #vim.api.nvim_list_wins() == 1 and vim.api.nvim_buf_get_name(0):match("NvimTree_") ~= nil then
			vim.cmd "quit"
		end
	end
})
